/*
 *  centerEl - v0.1.0
 *  vertically center elements relative to its parent
 *  https://geekymohan.wordpress.com/jquery-centerel-plugin/
 *
 *  Made by Mohan Dere
 *  Under MIT License
 */
;(function($, window, document, undefined) {

    "use strict";

    // Create the defaults once
    var pluginName = "centerEls",
        defaults = {
            additonalOffset: 0,
            absolutePositioning: 0,
            left : 0,
            right :0,
            bottom : 0,
            parentEl: "",
        };

    // The actual plugin constructor
    function CenterEls(element, options) {
        this.element = element;
        this.settings = $.extend({}, defaults, options);
        this._defaults = defaults;
        this._name = pluginName;
        this.init();
    }

    // Avoid Plugin.prototype conflicts
    CenterEls.prototype = {

        init: function() {


            if (!$(this.element).length) {
                return false;
            }
            if (!$(this.settings.parentEl).length) {
                return false;
            }

            this.center(this.element, this.settings);
        },
        center: function(el,settings){

            //iterate over each el  
            $(settings.parentEl).each(function() {
                var currentEl = $(this),
                    childEl = currentEl.find(el);


                if ( settings.absolutePositioning ) {
                    currentEl.css({
                        "position": "relative"
                    });

                    childEl.css({
                        "position": "absolute",
                        "top": ((currentEl.outerHeight() / 2) - (childEl.outerHeight() / 2) + settings.additonalOffset),
                        "left": settings.left,
                        "right": settings.right
                    });

                } else {

                    childEl.css({
                        "padding-top": ((currentEl.outerHeight() / 2) - (childEl.outerHeight() / 2) + settings.additonalOffset),
                    });
                }
            });
        },
        teardown: function(el,settings){

            //iterate over each el  
            $(settings.parentEl).each(function() {
                var currentEl = $(this),
                    childEl = currentEl.find(el);


                if ( settings.absolutePositioning ) {
                    currentEl.css({
                        "position": ""
                    });

                    childEl.css({
                        "position": "",
                        "top": "",
                        "left": "",
                        "right": ""
                    });

                } else {

                    childEl.css({
                        "padding-top": "",
                    });
                }
            });
        },    
        recalc: function() {
            this.center(this.element, this.settings);
        },
        destroy: function() {
             $.removeData(this, "plugin_" + pluginName);   
             this.teardown(this.element, this.settings);
        }
    };


    $.fn[pluginName] = function(options) {
        return this.each(function() {
            if (!$.data(this, "plugin_" + pluginName)) {
                $.data(this, "plugin_" + pluginName, new CenterEls(this, options));
            }
            else if ($.isFunction(CenterEls.prototype[options])) {
                $.data(this, "plugin_" + pluginName)[options]();
            }
        });
    };

})(jQuery, window, document);